==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LegendMouseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseEventArgsDescription } from "./LegendMouseEventArgsDescription";
/**
 * @hidden
 */
var LegendMouseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendMouseEventArgsDescriptionMetadata, _super);
    function LegendMouseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendMouseEventArgsDescriptionMetadata.b = function (a) {
        if (LegendMouseEventArgsDescriptionMetadata.a == null) {
            LegendMouseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendMouseEventArgsDescriptionMetadata.c(LegendMouseEventArgsDescriptionMetadata.a);
        }
        if (a.g(LegendMouseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(LegendMouseEventArgsDescriptionMetadata.a);
    };
    LegendMouseEventArgsDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
    };
    LegendMouseEventArgsDescriptionMetadata.d = function (a) {
        LegendMouseEventArgsDescriptionMetadata.b(a);
        a.u("LegendMouseEventArgs", function () { return new LegendMouseEventArgsDescription(); });
        a.t("LegendMouseEventArgs", LegendMouseEventArgsDescriptionMetadata.a);
    };
    LegendMouseEventArgsDescriptionMetadata.$t = markType(LegendMouseEventArgsDescriptionMetadata, 'LegendMouseEventArgsDescriptionMetadata');
    LegendMouseEventArgsDescriptionMetadata.a = null;
    return LegendMouseEventArgsDescriptionMetadata;
}(Base));
export { LegendMouseEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LegendMouseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseEventArgsDescription } from "./LegendMouseEventArgsDescription";
/**
 * @hidden
 */
var LegendMouseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendMouseEventArgsDescriptionMetadata, _super);
    function LegendMouseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendMouseEventArgsDescriptionMetadata.b = function (a) {
        if (LegendMouseEventArgsDescriptionMetadata.a == null) {
            LegendMouseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendMouseEventArgsDescriptionMetadata.c(LegendMouseEventArgsDescriptionMetadata.a);
        }
        if (a.j(LegendMouseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(LegendMouseEventArgsDescriptionMetadata.a);
    };
    LegendMouseEventArgsDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
    };
    LegendMouseEventArgsDescriptionMetadata.d = function (a) {
        LegendMouseEventArgsDescriptionMetadata.b(a);
        a.aa("LegendMouseEventArgs", function () { return new LegendMouseEventArgsDescription(); });
        a.z("LegendMouseEventArgs", LegendMouseEventArgsDescriptionMetadata.a);
    };
    LegendMouseEventArgsDescriptionMetadata.$t = markType(LegendMouseEventArgsDescriptionMetadata, 'LegendMouseEventArgsDescriptionMetadata');
    LegendMouseEventArgsDescriptionMetadata.a = null;
    return LegendMouseEventArgsDescriptionMetadata;
}(Base));
export { LegendMouseEventArgsDescriptionMetadata };
